SWDEV-339113 - Update sampl codes with correct kernel coordinate (#2704)

Change-Id: Ibfc0fd285441cd3d79b312d2b739729a039a6f84
Bu işleme şunda yer alıyor:
ROCm CI Service Account
2022-06-02 17:07:52 +05:30
işlemeyi yapan: GitHub
ebeveyn 7b0ed9e8d3
işleme 5da168300f
14 değiştirilmiş dosya ile 47 ekleme ve 47 silme
+2 -2
Dosyayı Görüntüle
@@ -37,8 +37,8 @@ THE SOFTWARE.
__global__ void matrixTranspose(float* out, float* in, const int width) {
extern __shared__ float sharedMem[];
int x = hipBlockDim_x * hipBlockIdx_x + hipThreadIdx_x;
int y = hipBlockDim_y * hipBlockIdx_y + hipThreadIdx_y;
int x = blockDim.x * blockIdx.x + threadIdx.x;
int y = blockDim.y * blockIdx.y + threadIdx.y;
sharedMem[y * width + x] = in[x * width + y];